package com.seeyon.ctp.organization.controller;

import com.seeyon.apps.collaboration.manager.ColManager;
import com.seeyon.ctp.common.AppContext;
import com.seeyon.ctp.common.authenticate.domain.User;
import com.seeyon.ctp.common.controller.BaseController;
import com.seeyon.ctp.organization.OrgConstants;
import com.seeyon.ctp.organization.OrgConstants.ROLE_BOND;
import com.seeyon.ctp.organization.OrgConstants.Role_NAME;
import com.seeyon.ctp.organization.bo.V3xOrgEntity;
import com.seeyon.ctp.organization.bo.V3xOrgMember;
import com.seeyon.ctp.organization.bo.V3xOrgRole;
import com.seeyon.ctp.organization.manager.OrgManager;
import com.seeyon.ctp.organization.manager.RoleManager;
import com.seeyon.ctp.organization.po.OrgMember;
import com.seeyon.ctp.util.Strings;
import com.seeyon.ctp.util.annotation.CheckRoleAccess;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.springframework.util.CollectionUtils;
import org.springframework.web.servlet.ModelAndView;

@CheckRoleAccess(
        roleTypes = {Role_NAME.GroupAdmin, Role_NAME.AccountAdministrator, Role_NAME.HrAdmin, Role_NAME.SystemAdmin}
)
public class RoleController extends BaseController {
    private RoleManager roleManager;
    private OrgManager orgManager;

    private ColManager colManager;

    public ColManager getColManager() {
        if (this.colManager == null) {
            this.colManager = (ColManager)AppContext.getBean("colManager");
        }

        return this.colManager;
    }

    public void setColManager(ColManager colManager) {
        this.colManager = colManager;
    }

    public RoleController() {
    }

    public ModelAndView showRoleList(HttpServletRequest request, HttpServletResponse response) throws Exception {
        ModelAndView mav = new ModelAndView("apps/organization/role/roleList");
        Long accountId = AppContext.currentAccountId();
        String accountIdStr = request.getParameter("accountId");
        if (Strings.isNotBlank(accountIdStr)) {
            accountId = Long.valueOf(accountIdStr);
        }
        User user = AppContext.getCurrentUser();
        if(user.getName().equals("系统管理员")){
            List<OrgMember> acc = colManager.selectacc("单位管理员");
            OrgMember use= acc.get(0);
            accountId = use.getOrgAccountId();
        }
        mav.addObject("accountId", accountId);
        mav.addObject("isGroup", OrgConstants.GROUPID.equals(accountId));
        return mav;
    }

    public ModelAndView showMember4Role(HttpServletRequest request, HttpServletResponse response) throws Exception {
        Long roleId = Long.parseLong(request.getParameter("roleId"));
        List<V3xOrgMember> members = this.orgManager.getMembersByRole(AppContext.currentAccountId(), roleId);
        if (!CollectionUtils.isEmpty(members)) {
            Iterator var5 = members.iterator();

            while(var5.hasNext()) {
                V3xOrgMember v3xOrgMember = (V3xOrgMember)var5.next();
                v3xOrgMember.setName("Member");
            }
        }

        request.setAttribute("members", members);
        HashMap m = new HashMap();
        m.put("flag", 0);
        if (this.orgManager.getRoleById(roleId).getBond() == ROLE_BOND.DEPARTMENT.ordinal()) {
            m.put("flag", 1);
        }

        request.setAttribute("isdeprole", m);
        return new ModelAndView("apps/organization/role/role4Member");
    }

    public ModelAndView showEntity4Role(HttpServletRequest request, HttpServletResponse response) throws Exception {
        Long roleId = Long.parseLong(request.getParameter("roleId"));
        Long accountId = Long.parseLong(request.getParameter("accountId"));
        List<V3xOrgEntity> entitys = this.orgManager.getEntitysByRole(accountId, roleId);
        request.setAttribute("members", entitys);
        HashMap m = new HashMap();
        m.put("flag", 0);
        if (this.orgManager.getRoleById(roleId).getBond() == ROLE_BOND.DEPARTMENT.ordinal()) {
            m.put("flag", 1);
        }

        request.setAttribute("isdeprole", m);
        request.setAttribute("roleId", roleId);
        request.setAttribute("accountId", accountId);
        request.setAttribute("isGroup", OrgConstants.GROUPID.equals(accountId));
        return new ModelAndView("apps/organization/role/role4Member");
    }

    public ModelAndView createRole(HttpServletRequest request, HttpServletResponse response) throws Exception {
        ModelAndView result = new ModelAndView("apps/organization/role/roleNew");
        Long accountId = AppContext.currentAccountId();
        String accountIdStr = request.getParameter("accountId");
        if (Strings.isNotBlank(accountIdStr)) {
            accountId = Long.valueOf(accountIdStr);
        }

        request.setAttribute("isGroup", OrgConstants.GROUPID.equals(accountId));
        Map<String, Object> roleMap = new HashMap();
        roleMap.put("accountId", accountId);
        roleMap.put("sortId", this.roleManager.getMaxSortId(accountId));
        request.setAttribute("ffmyfrm", roleMap);
        return result;
    }

    public ModelAndView showMembers4RoleCon(HttpServletRequest request, HttpServletResponse response) throws Exception {
        ModelAndView result = new ModelAndView("apps/organization/role/rolemembersList");
        request.setAttribute("roleid", request.getParameter("roleid"));
        request.setAttribute("bond", request.getParameter("bond"));
        return result;
    }

    public ModelAndView edit(HttpServletRequest request, HttpServletResponse response) throws Exception {
        Long menuId = Long.parseLong(request.getParameter("id"));
        V3xOrgRole role = this.roleManager.findById(menuId);
        Long accountId = AppContext.currentAccountId();
        String accountIdStr = request.getParameter("accountId");
        if (Strings.isNotBlank(accountIdStr)) {
            accountId = Long.valueOf(accountIdStr);
        }

        request.setAttribute("isGroup", OrgConstants.GROUPID.equals(accountId));
        Map<String, Object> roleMap = new HashMap();
        roleMap.put("id", String.valueOf(role.getId()));
        roleMap.put("name", role.getShowName());
        roleMap.put("code", role.getCode());
        roleMap.put("sortId", role.getSortId());
        roleMap.put("enable", role.getEnabled());
        roleMap.put("type", role.getType());
        roleMap.put("description", role.getDescription());
        roleMap.put("accountId", role.getOrgAccountId());
        roleMap.put("bond", role.getBond());
        roleMap.put("isBenchmark", role.getIsBenchmark());
        roleMap.put("category", role.getCategory());
        roleMap.put("status", role.getStatus());
        request.setAttribute("ffmyfrm", roleMap);
        return new ModelAndView("apps/organization/role/roleNew");
    }

    public void setRoleManager(RoleManager roleManager) {
        this.roleManager = roleManager;
    }

    public void setOrgManager(OrgManager orgManager) {
        this.orgManager = orgManager;
    }
}
