package com.seeyon.ctp.organization.inexportutil.manager;

import com.seeyon.ctp.common.AppContext;
import com.seeyon.ctp.common.authenticate.domain.User;
import com.seeyon.ctp.common.excel.DataRecord;
import com.seeyon.ctp.common.excel.DataRow;
import com.seeyon.ctp.common.excel.FileToExcelManager;
import com.seeyon.ctp.common.filemanager.manager.FileManager;
import com.seeyon.ctp.common.i18n.ResourceUtil;
import com.seeyon.ctp.common.metadata.manager.MetadataManager;
import com.seeyon.ctp.common.po.filemanager.V3XFile;
import com.seeyon.ctp.datasource.annotation.DataSourceName;
import com.seeyon.ctp.datasource.annotation.ProcessInDataSource;
import com.seeyon.ctp.organization.OrgConstants.Role_NAME;
import com.seeyon.ctp.organization.bo.V3xOrgAccount;
import com.seeyon.ctp.organization.dao.OrgCache;
import com.seeyon.ctp.organization.inexportutil.DataManager;
import com.seeyon.ctp.organization.inexportutil.DataUtil;
import com.seeyon.ctp.organization.manager.OrgManager;
import com.seeyon.ctp.organization.services.OrganizationServices;
import com.seeyon.ctp.util.Strings;
import com.seeyon.ctp.util.annotation.CheckRoleAccess;
import java.io.File;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.web.servlet.ModelAndView;

@ProcessInDataSource(
        name = DataSourceName.BASE
)
public class IOManagerImpl implements IOManager {
    private static final Log log = LogFactory.getLog(IOManagerImpl.class);
    OrganizationServices organizationServices;
    FileToExcelManager fileToExcelManager;
    private FileManager fileManager;
    private DataManager dataManagerImpl;
    private MetadataManager metadataManager;
    private OrgCache organization;
    protected OrgManager orgManager;
    User opUser = null;
    V3xOrgAccount vaccount = null;
    public static final String EXP_BASE_VIEW = "organization/expbase";
    public static final String EXP_REPEATER_VIEW = "organization/exprepeater";
    public static final String IMP_BASE_VIEW = "organization/impbase";
    public static final String PARA_TARGET_URL_BASE = "paratargeturl";
    public static final String PARA_TOMETHOD_BASE = "tomethod";
    public static final String PARA_METHOD_BASE = "method";

    public IOManagerImpl() {
    }

    public void setOrgManager(OrgManager orgManager) {
        this.orgManager = orgManager;
    }

    public OrgCache getOrganization() {
        return this.organization;
    }

    public void setOrganization(OrgCache organization) {
        this.organization = organization;
    }

    public MetadataManager getMetadataManager() {
        return this.metadataManager;
    }

    public void setMetadataManager(MetadataManager metadataManager) {
        this.metadataManager = metadataManager;
    }

    public DataManager getDataManagerImpl() {
        return this.dataManagerImpl;
    }

    public void setDataManagerImpl(DataManager dataManagerImpl) {
        this.dataManagerImpl = dataManagerImpl;
    }

    public FileManager getFileManager() {
        return this.fileManager;
    }

    public void setFileManager(FileManager fileManager) {
        this.fileManager = fileManager;
    }

    public OrganizationServices getOrganizationServices() {
        return this.organizationServices;
    }

    public void setOrganizationServices(OrganizationServices organizationServices) {
        this.organizationServices = organizationServices;
    }

    public FileToExcelManager getFileToExcelManager() {
        return this.fileToExcelManager;
    }

    public void setFileToExcelManager(FileToExcelManager fileToExcelManager) {
        this.fileToExcelManager = fileToExcelManager;
    }

    public ModelAndView exportReport(HttpServletRequest request, HttpServletResponse response) throws Exception {
        HttpSession session = request.getSession();
        DataRow[] datarow = (DataRow[])((DataRow[])session.getAttribute("datarowlist"));
        if (datarow == null) {
            List resultlst = (List)session.getAttribute("resultlst");
            datarow = DataUtil.createDataRowsFromResultObjects(resultlst);
        }

        String importType = (String)session.getAttribute("importType");
        String import_level_report = ResourceUtil.getString("import.level.report");
        String import_post_report = ResourceUtil.getString("import.post.report");
        String import_team_report = ResourceUtil.getString("import.team.report");
        String import_member_report = ResourceUtil.getString("import.member.report");
        String import_dept_report = ResourceUtil.getString("import.dept.report");
        String import_account_report = ResourceUtil.getString("import.account.report");
        String import_report = ResourceUtil.getString("import.report");
        String import_data = ResourceUtil.getString("import.data");
        String import_result = ResourceUtil.getString("import.result");
        String import_description = ResourceUtil.getString("import.description");
        String title = "";
        String sheetName = "";
        if ("level".equals(importType)) {
            title = import_level_report;
            sheetName = import_level_report;
        } else if ("post".equals(importType)) {
            title = import_post_report;
            sheetName = import_post_report;
        } else if ("team".equals(importType)) {
            title = import_team_report;
            sheetName = import_team_report;
        } else if ("member".equals(importType)) {
            title = import_member_report;
            sheetName = import_member_report;
        } else if ("department".equals(importType)) {
            title = import_dept_report;
            sheetName = import_dept_report;
        } else if ("account".equals(importType)) {
            title = import_account_report;
            sheetName = import_account_report;
        }

        DataRecord dataRecord = new DataRecord();

        try {
            dataRecord.addDataRow(datarow);
        } catch (Exception var22) {
            log.error(var22.getMessage(), var22);
        }

        String[] columnName = new String[]{import_data, import_result, import_description};
        dataRecord.setColumnName(columnName);
        dataRecord.setTitle(title);
        dataRecord.setSheetName(sheetName);

        try {
            this.fileToExcelManager.save(response, import_report, new DataRecord[]{dataRecord});
        } catch (Exception var21) {
            log.error("error", var21);
        }

        return null;
    }

    public ModelAndView importExcel(HttpServletRequest request, HttpServletResponse response) throws Exception {
        ModelAndView modelAndView = new ModelAndView("organization/selectImportExcel");
        String importType = request.getParameter("importType");
        modelAndView.addObject("importType", importType);
        HttpSession session = request.getSession();
        AppContext.putSessionContext("importType", importType);
        List<V3xOrgAccount> accountlst = this.getOrganizationServices().getOrgManager().getAllAccounts();
        modelAndView.addObject("accountlst", accountlst);
        return modelAndView;
    }

    public ModelAndView matchField(HttpServletRequest request, HttpServletResponse response) throws Exception {
        File file = this.uploadFile(request);
        if (file == null) {
            throw new Exception("未找到上传的文件！");
        } else {
            String path = file.getAbsolutePath() + ".xls";
            File realfile = new File(path);
            DataUtil.CopyFile(file, realfile);
            HttpSession session = request.getSession();
            String selectvalue = request.getParameter("selectvalue");
            AppContext.putSessionContext("selectvalue", selectvalue);
            if (selectvalue != null && !"".equals(selectvalue) && !"null".equals(selectvalue)) {
                String radiovalue = request.getParameter("radiovalue");
                AppContext.putSessionContext("radiovalue", radiovalue);
                String sheetnumber = request.getParameter("sheetnumber");
                AppContext.putSessionContext("sheetnumber", sheetnumber);
                if ("multi".equals(radiovalue) && (selectvalue == null || "".equals(selectvalue) || "null".equals(selectvalue))) {
                    throw new Exception("请选择上传表对应的工作簿的位置！");
                } else {
                    String language = request.getParameter("languagevalue");
                    AppContext.putSessionContext("language", language);
                    List<List<String>> accountList = null;
                    accountList = this.fileToExcelManager.readExcel(realfile);
                    if (accountList != null && accountList.size() > 2) {
                        log.info("read xls data:");

                        for(int i = 2; i < accountList.size(); ++i) {
                            log.info("accountList i=" + i);
                            List l = (List)accountList.get(i);
                            if (l == null) {
                                log.info("accountList'subList is null");
                            } else {
                                log.info("accountList'subList size=" + l.size());
                            }
                        }
                    }

                    AppContext.putSessionContext("excellst", accountList);
                    return null;
                }
            } else {
                throw new Exception("请上传文件对应的表！");
            }
        }
    }

    public ModelAndView matchField1(HttpServletRequest request, HttpServletResponse response) throws Exception {
        File file = this.uploadFile(request);
        if (file == null) {
            throw new Exception("未找到上传的文件！");
        } else {
            String path = file.getAbsolutePath() + ".xls";
            File realfile = new File(path);
            DataUtil.CopyFile(file, realfile);
            HttpSession session = request.getSession();
            String selectvalue = request.getParameter("selectvalue");
            AppContext.putSessionContext("selectvalue", selectvalue);
            if (selectvalue != null && !"".equals(selectvalue) && !"null".equals(selectvalue)) {
                String radiovalue = request.getParameter("radiovalue");
                AppContext.putSessionContext("radiovalue", radiovalue);
                String sheetnumber = request.getParameter("sheetnumber");
                AppContext.putSessionContext("sheetnumber", sheetnumber);
                if ("multi".equals(radiovalue) && (selectvalue == null || "".equals(selectvalue) || "null".equals(selectvalue))) {
                    throw new Exception("请选择上传表对应的工作簿的位置！");
                } else {
                    String language = request.getParameter("languagevalue");
                    AppContext.putSessionContext("language", language);
                    List datastrulst = this.getDataManagerImpl().getDataStructure(selectvalue);
                    DataUtil du = new DataUtil(selectvalue);
                    datastrulst = du.getCHNString(datastrulst, request);
                    AppContext.putSessionContext("datastrulst", datastrulst);
                    List<List<String>> accountList = null;
                    if ("multi".equals(radiovalue)) {
                        accountList = this.fileToExcelManager.readExcel(realfile);
                    } else if ("single".equals(radiovalue)) {
                        accountList = this.fileToExcelManager.readExcel(realfile);
                        if (accountList != null && accountList.size() > 2) {
                            log.info("read xls data:");

                            for(int i = 2; i < accountList.size(); ++i) {
                                log.info("accountList i=" + i);
                                List l = (List)accountList.get(i);
                                if (l == null) {
                                    log.info("accountList'subList is null");
                                } else {
                                    log.info("accountList'subList size=" + l.size());
                                }
                            }
                        }
                    }

                    AppContext.putSessionContext("excellst", accountList);
                    PrintWriter out = response.getWriter();
                    out.println("<script>");
                    out.println("parent.getA8Top().contentFrame.topFrame.matchfiled();");
                    out.println("</script>");
                    return null;
                }
            } else {
                throw new Exception("请上传文件对应的表！");
            }
        }
    }

    public ModelAndView popMatchPage(HttpServletRequest request, HttpServletResponse response) throws Exception {
        HttpSession session = request.getSession();
        ModelAndView modelAndView = new ModelAndView("organization/matchField");
        Map allmap = (Map)session.getAttribute("allmap");
        modelAndView.addObject("matchlst", allmap.get("0"));
        modelAndView.addObject("excellst", allmap.get("1"));
        modelAndView.addObject("strulst", allmap.get("2"));
        modelAndView.addObject("language", (String)session.getAttribute("language"));
        modelAndView.addObject("selectvalue", (String)session.getAttribute("selectvalue"));
        modelAndView.addObject("radiovalue", (String)session.getAttribute("radiovalue"));
        modelAndView.addObject("sheetnumber", (String)session.getAttribute("sheetnumber"));
        session.removeAttribute("allmap");
        return modelAndView;
    }

    public ModelAndView importReport(HttpServletRequest request, HttpServletResponse response) throws Exception {
        ModelAndView modelAndView = new ModelAndView("apps/organization/common/importReport");
        HttpSession session = request.getSession();
        if (null == request.getParameter("page")) {
            session.setAttribute("resultlst", (Object)null);
        }

        String selectvalue = request.getParameter("selectvalue");
        if (selectvalue != null && !"".equals(selectvalue) && !"null".equals(selectvalue)) {
            String repeat = request.getParameter("repeat");
            String onlytag = request.getParameter("onlytag") == null ? "name" : request.getParameter("onlytag");
            String language = request.getParameter("language");
            if (Strings.isBlank(language)) {
                language = "zh_CN";
            }

            String impURL = request.getParameter("impURL");
            if (!Strings.isNotBlank(impURL)) {
                impURL = (String)session.getAttribute("impURL");
            }

            log.info("impURL=" + impURL);
            List resultlst = (List)session.getAttribute("resultlst");
            if (resultlst == null) {
                resultlst = DataUtil.getResult4Imp(selectvalue);
            }

            if (resultlst == null) {
                resultlst = new ArrayList();
            }

            modelAndView.addObject("selectvalue", selectvalue);
            AppContext.putSessionContext("selectvalue", selectvalue);
            AppContext.putSessionContext("importType", selectvalue);
            modelAndView.addObject("repeat", repeat);
            AppContext.putSessionContext("repeat", repeat);
            modelAndView.addObject("onlytag", onlytag);
            AppContext.putSessionContext("onlytag", onlytag);
            modelAndView.addObject("language", language);
            AppContext.putSessionContext("language", language);
            modelAndView.addObject("impURL", impURL);
            AppContext.putSessionContext("impURL", impURL);
            List subl = DataUtil.pageForList((List)resultlst);
            session.setAttribute("resultlst", resultlst);
            modelAndView.addObject("resultlst", subl);
            return modelAndView;
        } else {
            throw new Exception("请上传文件对应的表！");
        }
    }

    public String doImport4Redirect(HttpServletRequest request, HttpServletResponse response) throws Exception {
        HttpSession session = request.getSession();
        String selectvalue = request.getParameter("selectvalue");
        if (selectvalue == null) {
            selectvalue = (String)request.getAttribute("selectvalue");
        }

        if (selectvalue != null && !"".equals(selectvalue) && !"null".equals(selectvalue)) {
            File file = this.uploadFile(request);
            if (file == null) {
                return "";
            } else {
                String path = file.getAbsolutePath() + file.getName();
                File realfile = new File(path);
                DataUtil.CopyFile(file, realfile);
                AppContext.putSessionContext("selectvalue", selectvalue);
                if (selectvalue != null && !"".equals(selectvalue) && !"null".equals(selectvalue)) {
                    String radiovalue = request.getParameter("radiovalue");
                    AppContext.putSessionContext("radiovalue", radiovalue);
                    String sheetnumber = request.getParameter("sheetnumber");
                    AppContext.putSessionContext("sheetnumber", sheetnumber);
                    if ("multi".equals(radiovalue) && (selectvalue == null || "".equals(selectvalue) || "null".equals(selectvalue))) {
                        throw new Exception("请选择上传表对应的工作簿的位置！");
                    } else {
                        String repeat = request.getParameter("repeat");
                        boolean ignoreWhenUpdate = !"0".equals(repeat);
                        String onlytag = request.getParameter("onlytag") == null ? "name" : request.getParameter("onlytag");
                        String language = request.getParameter("language");
                        if (Strings.isBlank(language)) {
                            language = "zh_CN";
                        }

                        AppContext.putSessionContext("language", language);
                        String impURL = request.getParameter("impURL");
                        AppContext.putSessionContext("impURL", impURL);
                        List<List<String>> accountList = null;
                        List reall = new ArrayList();
                        accountList = this.fileToExcelManager.readExcel(realfile);
                        String deptOrRole = null;
                        if (accountList != null && accountList.size() > 2) {
                            log.info("read xls data:");

                            for(int i = 2; i < accountList.size(); ++i) {
                                List l = (List)accountList.get(i);
                                if (l == null) {
                                    log.info("accountList'subList is null");
                                }
                            }

                            reall = accountList.subList(!"department".equals(selectvalue) && !"businessDepartment".equals(selectvalue) ? 3 : 0, accountList.size());
                        }

                        DataUtil du = new DataUtil(selectvalue);
                        Map reportmap = du.getIip().importOrg(this.organizationServices, this.metadataManager, (List)reall, this.getVaccount(), ignoreWhenUpdate, onlytag);
                        List resultlst = this.createResultObjectList(reportmap);
                        AppContext.putSessionContext("resultlst", resultlst);
                        DataUtil.putResult4Imp(selectvalue, resultlst);
                        return DataUtil.getImportReportURL(selectvalue, repeat, language, impURL);
                    }
                } else {
                    throw new Exception("请上传文件对应的表！");
                }
            }
        } else {
            throw new Exception("请上传文件对应的表！");
        }
    }

    public ModelAndView doImport(HttpServletRequest request, HttpServletResponse response) throws Exception {
        ModelAndView modelAndView = new ModelAndView("organization/importReport");
        HttpSession session = request.getSession();
        String selectvalue = request.getParameter("selectvalue");
        if (selectvalue != null && !"".equals(selectvalue) && !"null".equals(selectvalue)) {
            File file = this.uploadFile(request);
            String path = file.getAbsolutePath() + ".xls";
            File realfile = new File(path);
            DataUtil.CopyFile(file, realfile);
            AppContext.putSessionContext("selectvalue", selectvalue);
            if (selectvalue != null && !"".equals(selectvalue) && !"null".equals(selectvalue)) {
                String radiovalue = request.getParameter("radiovalue");
                AppContext.putSessionContext("radiovalue", radiovalue);
                String sheetnumber = request.getParameter("sheetnumber");
                AppContext.putSessionContext("sheetnumber", sheetnumber);
                if (!"multi".equals(radiovalue) || selectvalue != null && !"".equals(selectvalue) && !"null".equals(selectvalue)) {
                    String repeat = request.getParameter("repeat");
                    boolean ignoreWhenUpdate = !"0".equals(repeat);
                    String onlytag = request.getParameter("onlytag") == null ? "name" : request.getParameter("onlytag");
                    String language = request.getParameter("language");
                    modelAndView.addObject("language", language);
                    AppContext.putSessionContext("language", language);
                    Locale locale = null;
                    if ("zh_CN".equals(language)) {
                        locale = Locale.CHINA;
                    } else if ("en".equals(language)) {
                        locale = Locale.ENGLISH;
                    } else if ("zh".equals(language)) {
                        locale = Locale.TAIWAN;
                    }

                    String impURL = request.getParameter("impURL");
                    modelAndView.addObject("impURL", impURL);
                    List<List<String>> accountList = null;
                    accountList = this.fileToExcelManager.readExcel(realfile);
                    if (accountList != null && accountList.size() > 2) {
                        log.info("read xls data:");

                        for(int i = 2; i < accountList.size(); ++i) {
                            log.info("accountList i=" + i);
                            List l = (List)accountList.get(i);
                            if (l == null) {
                                log.info("accountList'subList is null");
                            } else {
                                log.info("accountList'subList size=" + l.size());
                            }
                        }
                    }

                    List reall = new ArrayList();
                    if (null != accountList && accountList.size() > 2) {
                        reall = accountList.subList(2, accountList.size());
                    }

                    DataUtil du = new DataUtil(selectvalue);
                    Map reportmap = du.getIip().importOrg(this.organizationServices, this.metadataManager, (List)reall, this.getVaccount(), ignoreWhenUpdate, onlytag);
                    List resultlst = this.createResultObjectList(reportmap);
                    AppContext.putSessionContext("resultlst", resultlst);
                    modelAndView.addObject("resultlst", resultlst);
                    modelAndView.addObject("repeat", repeat);
                    PrintWriter out = response.getWriter();
                    out.println("<script>");
                    out.println("parent.closeOnbeforeunload('?method=);");
                    out.println("</script>");
                    return null;
                } else {
                    throw new Exception("请选择上传表对应的工作簿的位置！");
                }
            } else {
                throw new Exception("请上传文件对应的表！");
            }
        } else {
            throw new Exception("请上传文件对应的表！");
        }
    }

    private File uploadFile(HttpServletRequest request) throws Exception {
        new HashMap();
        File fil = null;

        try {
            V3XFile v3x = null;
            Map<String, V3XFile> v3xFiles = this.fileManager.uploadFiles(request, "xls,xlsx", (Long)null);
            String key = "";
            if (v3xFiles != null) {
                for(Iterator keys = v3xFiles.keySet().iterator(); keys.hasNext(); v3x = (V3XFile)v3xFiles.get(key)) {
                    key = (String)keys.next();
                }
            }

            if (null != v3x) {
                fil = this.fileManager.getFile(v3x.getId(), v3x.getCreateDate());
            }
        } catch (Exception var7) {
            log.error("", var7);
        }

        return fil;
    }

    public ModelAndView expOrgToExcel(HttpServletRequest request, HttpServletResponse response) throws Exception {
        return null;
    }

    public User getOpUser() {
        return this.opUser;
    }

    public void setOpUser(User opUser) {
        this.opUser = opUser;
    }

    public V3xOrgAccount getVaccount() {
        return this.vaccount;
    }

    public void setVaccount(V3xOrgAccount vaccount) {
        this.vaccount = vaccount;
    }

    public void setVaccountByUser(Long accountId) {
        try {
            V3xOrgAccount vao = this.orgManager.getAccountById(accountId);
            this.setVaccount(vao);
        } catch (Exception var3) {
            log.error("error", var3);
        }

    }

    public List createResultObjectList(Map resultMap) {
        ArrayList l = new ArrayList();

        try {
            List errorl = (List)resultMap.get("error");
            if (errorl != null) {
                l.addAll(errorl);
            }

            List ignorel = (List)resultMap.get("ignore");
            if (ignorel != null) {
                l.addAll(ignorel);
            }

            List addl = (List)resultMap.get("add");
            if (addl != null) {
                l.addAll(addl);
            }

            List updatel = (List)resultMap.get("update");
            if (updatel != null) {
                l.addAll(updatel);
            }

            List nitexistl = (List)resultMap.get("notexist");
            if (nitexistl != null) {
                l.addAll(nitexistl);
            }
        } catch (Exception var8) {
            log.error("error", var8);
        }

        return l;
    }

    public void writeExpEndProcScript(HttpServletRequest request, HttpServletResponse response) throws Exception {
        PrintWriter out = response.getWriter();
        out.println("<script>");
        out.println("parent.closeOnbeforeunload();");
        out.println("</script>");
    }

    public ModelAndView toExpRepeater(HttpServletRequest request, HttpServletResponse response, String url) throws Exception {
        ModelAndView mv = new ModelAndView("organization/exprepeater");
        mv.addObject("paratargeturl", url);
        return mv;
    }

    public ModelAndView toImpBase(HttpServletRequest request, HttpServletResponse response) throws Exception {
        return this.toBaseJSP(request, response, "organization/impbase");
    }

    public ModelAndView toExpBase(HttpServletRequest request, HttpServletResponse response) throws Exception {
        return this.toBaseJSP(request, response, "organization/expbase");
    }

    protected ModelAndView toBaseJSP(HttpServletRequest request, HttpServletResponse response, String viewname) throws Exception {
        ModelAndView mv = new ModelAndView(viewname);
        String qStr4BaseJsp = this.getQueryString4BaseJsp(request, response);
        mv.addObject("paratargeturl", qStr4BaseJsp);
        return mv;
    }

    protected String getQueryString4BaseJsp(HttpServletRequest request, HttpServletResponse response) throws Exception {
        String org = request.getQueryString();
        log.info("QueryString=" + org);
        if (!Strings.isNotBlank(org)) {
            return org;
        } else {
            int mt = org.indexOf("tomethod");
            return mt < 0 ? org : org.substring(mt + 2);
        }
    }

    @CheckRoleAccess(
            roleTypes = {Role_NAME.SystemAdmin,Role_NAME.GroupAdmin, Role_NAME.AccountAdministrator, Role_NAME.HrAdmin, Role_NAME.BusinessOrganizationManager}
    )
    public String canIO() throws Exception {
        return this.canIO(this.catchCurrentUser());
    }

    public String canIO(User u) throws Exception {
        return u == null ? "nouser" : this.canIO(u.getId());
    }

    public String canIO(long userid) throws Exception {
        return DataUtil.doingImpExp(userid) ? "doing" : "ok";
    }

    public String canIO(String userid) throws Exception {
        try {
            return this.canIO(Long.parseLong(userid));
        } catch (Exception var3) {
            return this.canIO();
        }
    }

    private User catchCurrentUser() {
        return AppContext.getCurrentUser();
    }
}